@@ -9,13 +9,19 @@ module GLib
   class List
     include ListMethods
 
-    def self.from_enumerable(type, arr)
-      arr.reduce(new(type)) { |lst, val| lst.append val }
+    def append(data)
+      store_pointer Lib.g_list_append(self, element_ptr_for(data))
+      self
     end
 
-    def append(data)
-      self.class.wrap(element_type,
-                      Lib.g_list_append(self, element_ptr_for(data)))
+    def prepend(data)
+      store_pointer Lib.g_list_prepend(self, element_ptr_for(data))
+      self
+    end
+
+    def reverse
+      store_pointer Lib.g_list_reverse(self)
+      self
     end
   end
 end
