@@ -58,8 +58,8 @@ module GLib
       current_loop.quit
     end
 
-    alias run_without_thread_enabler run
-    alias run run_with_thread_enabler
+    alias_method :run_without_thread_enabler, :run
+    alias_method :run, :run_with_thread_enabler
   end
 end
 
