@@ -31,17 +31,6 @@ module GObject
     type_name type_from_instance instance
   end
 
-  def self.object_class_from_instance(instance)
-    object_class_from_instance_pointer instance.to_ptr
-  end
-
-  def self.object_class_from_instance_pointer(inst_ptr)
-    return nil if inst_ptr.null?
-
-    klsptr = inst_ptr.get_pointer 0
-    ObjectClass.wrap klsptr
-  end
-
   def self.signal_lookup_from_instance(signal, object)
     signal_lookup signal, type_from_instance(object)
   end
@@ -55,11 +44,7 @@ module GObject
     argument_gvalues = sig_info.arguments_to_gvalues object, args
     return_gvalue = sig_info.gvalue_for_return_value
 
-    result = signal_emitv argument_gvalues, signal_id, detail_quark, return_gvalue
-    # NOTE: Depending on the version of GObjectIntrospection, the result will
-    # be stored in result or return_gvalue. This was changed between versions
-    # 1.44 and 1.46.
-    result || return_gvalue.get_value
+    signal_emitv argument_gvalues, signal_id, detail_quark, return_gvalue
   end
 
   def self.signal_connect(object, detailed_signal, data = nil, after = false, &block)
@@ -85,7 +70,8 @@ module GObject
   load_class :ClosureMarshal
   load_class :ParamFlags
 
-  # NOTE: This Lib module is set up in `gir_ffi-base/gobject/lib.rb`.
+  # Attach some needed functions to the GObject Lib, which was set up in
+  # `gir_ffi-base/gobject/lib.rb`.
   Lib.class_eval do
     attach_function :g_object_ref_sink, [:pointer], :pointer
     attach_function :g_object_ref, [:pointer], :pointer
