@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'ffi-gobject_introspection/i_base_info'
+require "ffi-gobject_introspection/i_base_info"
 module GObjectIntrospection
   # Wraps a GIArgInfo struct.
   # Represents an argument.
@@ -46,7 +46,7 @@ module GObjectIntrospection
     end
 
     def argument_type
-      ITypeInfo.wrap Lib.g_arg_info_get_type(self)
+      @argument_type ||= ITypeInfo.wrap Lib.g_arg_info_get_type(self)
     end
   end
 end
