@@ -21,7 +21,7 @@ module GObjectIntrospection
     end
 
     def parent
-      IObjectInfo.wrap Lib.g_object_info_get_parent(self)
+      @parent ||= IObjectInfo.wrap Lib.g_object_info_get_parent(self)
     end
 
     def n_interfaces
@@ -59,7 +59,7 @@ module GObjectIntrospection
     end
 
     def find_property(name)
-      name = name.to_s.tr('_', '-')
+      name = name.to_s.tr("_", "-")
       properties.find { |prop| prop.name == name }
     end
 
