@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'ffi-gobject_introspection/i_base_info'
+require "ffi-gobject_introspection/i_base_info"
 
 module GObjectIntrospection
   # Wraps a GIBaseInfo struct in the case where the info type is :unresolved.
