@@ -5,4 +5,4 @@
 # that can only be created fully once GirFFI is fully loaded.
 
 # Some base GObject functions and constants are needed by GirFFI.
-require 'gir_ffi-base/gobject'
+require "gir_ffi-base/gobject"
