@@ -5,19 +5,12 @@ module GirFFI
     # Builder that generates code to convert closure arguments ('user data')
     # from Ruby to C. Used by argument builders.
     class ClosureToPointerConvertor
-      def initialize(argument_name, callback_argument)
+      def initialize(argument_name)
         @argument_name = argument_name
-        @callback_argument = callback_argument
       end
 
       def conversion
-        "GirFFI::ArgHelper.store(#{callback_argument_name})"
-      end
-
-      private
-
-      def callback_argument_name
-        @callback_argument.call_argument_name
+        "GirFFI::ArgHelper.store(#{@argument_name})"
       end
     end
   end
