@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/builders/base_return_value_builder'
+require "gir_ffi/builders/base_return_value_builder"
 
 module GirFFI
   module Builders
@@ -9,7 +9,7 @@ module GirFFI
       def post_conversion
         result = []
         result << "store_pointer(#{capture_variable_name})"
-        result << '@struct.owned = true' if specialized_type_tag == :struct
+        result << "@struct.owned = true" if specialized_type_tag == :struct
         result
       end
     end
