@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/builders/registered_type_builder'
-require 'gir_ffi/builders/struct_like'
+require "gir_ffi/builders/registered_type_builder"
+require "gir_ffi/builders/struct_like"
 
 module GirFFI
   module Builders
