@@ -1,11 +1,11 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/return_value_info'
-require 'gir_ffi/builders/base_type_builder'
-require 'gir_ffi/builders/mapping_method_builder'
-require 'gir_ffi/receiver_type_info'
-require 'gir_ffi/receiver_argument_info'
-require 'gir_ffi/callback_base'
+require "gir_ffi/return_value_info"
+require "gir_ffi/builders/base_type_builder"
+require "gir_ffi/builders/mapping_method_builder"
+require "gir_ffi/receiver_type_info"
+require "gir_ffi/receiver_argument_info"
+require "gir_ffi/callback_base"
 
 module GirFFI
   module Builders
@@ -42,8 +42,8 @@ module GirFFI
       end
 
       def argument_ffi_types
-        @argument_ffi_types ||= info.argument_ffi_types.
-          unshift(receiver_type_info.to_callback_ffi_type)
+        @argument_ffi_types ||= info.argument_ffi_types
+          .unshift(receiver_type_info.to_callback_ffi_type)
       end
 
       def return_ffi_type
