@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/info_ext/i_type_info'
+require "gir_ffi/info_ext/i_type_info"
 
 module GirFFI
   # Represents the type of an error argument for callbacks and functions,
