@@ -17,8 +17,14 @@ module GirFFI
       end
 
       def arguments_to_gvalues(instance, arguments)
-        arg_g_values = argument_types.zip(arguments).map do |type, arg|
-          type.make_g_value.tap { |it| it.set_value arg }
+        arg_g_values = args.zip(arguments).map do |arg_info, arg|
+          case arg_info.direction
+          when :in
+            type = arg_info.argument_type
+            type.make_g_value.tap { |it| it.set_value arg }
+          else
+            raise NotImplementedError
+          end
         end
 
         arg_g_values.unshift GObject::Value.wrap_instance(instance)
@@ -27,10 +33,6 @@ module GirFFI
       def gvalue_for_return_value
         return_type.make_g_value
       end
-
-      def argument_types
-        @argument_types ||= args.map(&:argument_type)
-      end
     end
   end
 end
